@@ -20,11 +20,12 @@
 #include <QDesktopWidget>
 #include <QToolButton>
 #include <QMessageBox>
+#include <QTimer>
 #include <functional>
 
 #ifdef HAVE_QDBUS
-    #include <QtDBus/QtDBus>
-    #include "windowadaptor.h"
+#include <QtDBus/QtDBus>
+#include "windowadaptor.h"
 #endif
 
 #include "terminalconfig.h"
@@ -38,7 +39,7 @@
 #include "qterminalapp.h"
 #include "dbusaddressable.h"
 
-typedef std::function<bool(MainWindow&)> checkfn;
+typedef std::function<bool(MainWindow&, QAction *)> checkfn;
 Q_DECLARE_METATYPE(checkfn)
 
 // TODO/FXIME: probably remove. QSS makes it unusable on mac...
@@ -50,16 +51,16 @@ MainWindow::MainWindow(TerminalConfig &cfg,
                        Qt::WindowFlags f)
     : QMainWindow(parent,f),
       DBusAddressable(QStringLiteral("/windows")),
-      tabPosition(NULL),
-      scrollBarPosition(NULL),
-      keyboardCursorShape(NULL),
-      tabPosMenu(NULL),
-      scrollPosMenu(NULL),
-      keyboardCursorShapeMenu(NULL),
-      settingOwner(NULL),
-      presetsMenu(NULL),
+      tabPosition(nullptr),
+      scrollBarPosition(nullptr),
+      keyboardCursorShape(nullptr),
+      tabPosMenu(nullptr),
+      scrollPosMenu(nullptr),
+      keyboardCursorShapeMenu(nullptr),
+      settingOwner(nullptr),
+      presetsMenu(nullptr),
       m_config(cfg),
-      m_dropLockButton(0),
+      m_dropLockButton(nullptr),
       m_dropMode(dropMode)
 {
 #ifdef HAVE_QDBUS
@@ -76,6 +77,17 @@ MainWindow::MainWindow(TerminalConfig &cfg,
 
     setupUi(this);
 
+    // Allow insane small sizes - reason:
+    // https://github.com/lxqt/qterminal/issues/181 - Minimum size
+    // https://github.com/lxqt/qterminal/issues/263 - Decrease minimal height
+    QFontMetrics metrics(Properties::Instance()->font);
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+    int spaceWidth = metrics.horizontalAdvance(QChar(QChar::Space));
+#else
+    int spaceWidth = metrics.width(QChar(QChar::Space));
+#endif
+    setMinimumSize(QSize(10 * spaceWidth, metrics.height()));
+
     m_bookmarksDock = new QDockWidget(tr("Bookmarks"), this);
     m_bookmarksDock->setObjectName(QStringLiteral("BookmarksDockWidget"));
     m_bookmarksDock->setAutoFillBackground(true);
@@ -99,12 +111,16 @@ MainWindow::MainWindow(TerminalConfig &cfg,
         setStyleSheet(QStringLiteral(QSS_DROP));
     }
     else {
-	if (Properties::Instance()->saveSizeOnExit) {
-	    resize(Properties::Instance()->mainWindowSize);
-	}
-	if (Properties::Instance()->savePosOnExit) {
-	    move(Properties::Instance()->mainWindowPosition);
-	}
+        if (Properties::Instance()->saveSizeOnExit) {
+            if (Properties::Instance()->mainWindowSize.isValid())
+                resize(Properties::Instance()->mainWindowSize);
+        }
+        else if (Properties::Instance()->fixedWindowSize.isValid()) {
+            resize(Properties::Instance()->fixedWindowSize);
+        }
+        if (Properties::Instance()->savePosOnExit && !Properties::Instance()->mainWindowPosition.isNull()) {
+            move(Properties::Instance()->mainWindowPosition);
+        }
         restoreState(Properties::Instance()->mainWindowState);
     }
 
@@ -113,6 +129,10 @@ MainWindow::MainWindow(TerminalConfig &cfg,
     consoleTabulator->setTabPosition((QTabWidget::TabPosition)Properties::Instance()->tabsPos);
     //consoleTabulator->setShellProgram(command);
 
+    const auto menuBarActions = m_menuBar->actions();
+    for (const auto& action : menuBarActions)
+        menubarOrigTexts << action->text();
+
     // apply props
     propertiesChanged();
 
@@ -206,6 +226,7 @@ void MainWindow::setup_ActionsMenu_Actions()
 
     const checkfn checkTabs = &MainWindow::hasMultipleTabs;
     const checkfn checkSubterminals = &MainWindow::hasMultipleSubterminals;
+    const checkfn checkHasIndexedTab = &MainWindow::hasIndexedTab;
 
     menu_Actions->clear();
 
@@ -234,18 +255,32 @@ void MainWindow::setup_ActionsMenu_Actions()
     setup_Action(MOVE_RIGHT, new QAction(tr("Move Tab &Right"), settingOwner),
                  MOVE_RIGHT_SHORTCUT, consoleTabulator, SLOT(moveRight()), menu_Actions, data);
 
+    data.setValue(checkHasIndexedTab);
+
+    const QString textBase = tr("Tab");
+    QMenu *menu_GoTo = new QMenu(tr("Go to"), menu_Actions);
+    for (int i=1; i<=10; ++i) {
+        QString num = QString::number(i);
+        QAction *action = new QAction(textBase + QLatin1Char(' ') + num, settingOwner);
+        action->setProperty("tab", i);
+        char name[16];
+        snprintf(name, sizeof(name), "Tab %d", i);
+        setup_Action(name, action, NULL, consoleTabulator, SLOT(onAction()), menu_GoTo, data);
+    }
+    menu_Actions->addMenu(menu_GoTo);
+
     menu_Actions->addSeparator();
 
     setup_Action(SPLIT_HORIZONTAL, new QAction(tr("Split Terminal &Horizontally"), settingOwner),
-                 NULL, consoleTabulator, SLOT(splitHorizontally()), menu_Actions);
+                 nullptr, consoleTabulator, SLOT(splitHorizontally()), menu_Actions);
 
     setup_Action(SPLIT_VERTICAL, new QAction(tr("Split Terminal &Vertically"), settingOwner),
-                 NULL, consoleTabulator, SLOT(splitVertically()), menu_Actions);
+                 nullptr, consoleTabulator, SLOT(splitVertically()), menu_Actions);
 
     data.setValue(checkSubterminals);
 
     setup_Action(SUB_COLLAPSE, new QAction(tr("&Collapse Subterminal"), settingOwner),
-                 NULL, consoleTabulator, SLOT(splitCollapse()), menu_Actions, data);
+                 nullptr, consoleTabulator, SLOT(splitCollapse()), menu_Actions, data);
 
     setup_Action(SUB_TOP, new QAction(QIcon::fromTheme(QStringLiteral("go-up")), tr("&Top Subterminal"), settingOwner),
                  SUB_TOP_SHORTCUT, consoleTabulator, SLOT(switchTopSubterminal()), menu_Actions, data);
@@ -286,6 +321,9 @@ void MainWindow::setup_ActionsMenu_Actions()
     setup_Action(FIND, new QAction(QIcon::fromTheme(QStringLiteral("edit-find")), tr("&Find..."), settingOwner),
                  FIND_SHORTCUT, this, SLOT(find()), menu_Actions);
 
+    setup_Action(HANDLE_HISTORY, new QAction(QIcon::fromTheme(QStringLiteral("handle-history")), tr("Handle history..."), settingOwner),
+                 NULL, this, SLOT(handleHistory()), menu_Actions);
+
 #if 0
     act = new QAction(this);
     act->setSeparator(true);
@@ -314,13 +352,14 @@ void MainWindow::setup_ActionsMenu_Actions()
     // this is correct - add action to main window - not to menu
 
 }
+
 void MainWindow::setup_FileMenu_Actions()
 {
     menu_File->clear();
     setup_Action(ADD_TAB, new QAction(QIcon::fromTheme(QStringLiteral("list-add")), tr("&New Tab"), settingOwner),
                  ADD_TAB_SHORTCUT, this, SLOT(addNewTab()), menu_File);
 
-    if (presetsMenu == NULL) {
+    if (presetsMenu == nullptr) {
         presetsMenu = new QMenu(tr("New Tab From &Preset"), this);
         presetsMenu->addAction(QIcon(), tr("1 &Terminal"),
                                this, SLOT(addNewTab()));
@@ -355,20 +394,27 @@ void MainWindow::setup_ViewMenu_Actions()
     QAction *hideBordersAction = new QAction(tr("&Hide Window Borders"), settingOwner);
     hideBordersAction->setCheckable(true);
     hideBordersAction->setVisible(!m_dropMode);
+
+    hideBordersAction->setChecked(Properties::Instance()->borderless);
+    if (!m_dropMode) // dropdown mode doesn't need any change
+    {
+        if (!testAttribute(Qt::WA_WState_Created)) // called by c-tor
+        {
+            if (Properties::Instance()->borderless)
+                setWindowFlags(windowFlags() ^ Qt::FramelessWindowHint);
+        }
+        else if (Properties::Instance()->borderless != windowFlags().testFlag(Qt::FramelessWindowHint))
+            QTimer::singleShot(0, this, &MainWindow::toggleBorderless); // called by PropertiesDialog
+    }
     setup_Action(HIDE_WINDOW_BORDERS, hideBordersAction,
-                 NULL, this, SLOT(toggleBorderless()), menu_Window);
-    //Properties::Instance()->actions[HIDE_WINDOW_BORDERS]->setObjectName("toggle_Borderless");
-// TODO/FIXME: it's broken somehow. When I call toggleBorderless() here the non-responsive window appear
-//    actions[HIDE_WINDOW_BORDERS]->setChecked(Properties::Instance()->borderless);
-//    if (Properties::Instance()->borderless)
-//        toggleBorderless();
+                 nullptr, this, SLOT(toggleBorderless()), menu_Window);
 
     QAction *showTabBarAction = new QAction(tr("&Show Tab Bar"), settingOwner);
     //toggleTabbar->setObjectName("toggle_TabBar");
     showTabBarAction->setCheckable(true);
     showTabBarAction->setChecked(!Properties::Instance()->tabBarless);
     setup_Action(SHOW_TAB_BAR, showTabBarAction,
-                 NULL, this, SLOT(toggleTabBar()), menu_Window);
+                 nullptr, this, SLOT(toggleTabBar()), menu_Window);
     toggleTabBar();
 
     QAction *toggleFullscreen = new QAction(tr("Fullscreen"), settingOwner);
@@ -378,12 +424,12 @@ void MainWindow::setup_ViewMenu_Actions()
                  FULLSCREEN_SHORTCUT, this, SLOT(showFullscreen(bool)), menu_Window);
 
     setup_Action(TOGGLE_BOOKMARKS, new QAction(tr("Toggle Bookmarks"), settingOwner),
-                 TOGGLE_BOOKMARKS_SHORTCUT, NULL, NULL, menu_Window);
+                 TOGGLE_BOOKMARKS_SHORTCUT, this, SLOT(toggleBookmarks()), menu_Window);
 
     menu_Window->addSeparator();
 
     /* tabs position */
-    if (tabPosition == NULL) {
+    if (tabPosition == nullptr) {
         tabPosition = new QActionGroup(this);
         QAction *tabBottom = new QAction(tr("&Bottom"), this);
         QAction *tabTop = new QAction(tr("&Top"), this);
@@ -403,9 +449,9 @@ void MainWindow::setup_ViewMenu_Actions()
         tabPosition->actions().at(Properties::Instance()->tabsPos)->setChecked(true);
 
     connect(tabPosition, &QActionGroup::triggered,
-             consoleTabulator, &TabWidget::changeTabPosition);
+            consoleTabulator, &TabWidget::changeTabPosition);
 
-    if (tabPosMenu == NULL) {
+    if (tabPosMenu == nullptr) {
         tabPosMenu = new QMenu(tr("&Tabs Layout"), menu_Window);
         tabPosMenu->setObjectName(QStringLiteral("tabPosMenu"));
 
@@ -420,7 +466,7 @@ void MainWindow::setup_ViewMenu_Actions()
     /* */
 
     /* Scrollbar */
-    if (scrollBarPosition == NULL) {
+    if (scrollBarPosition == nullptr) {
         scrollBarPosition = new QActionGroup(this);
         QAction *scrollNone = new QAction(tr("&None"), this);
         QAction *scrollRight = new QAction(tr("&Right"), this);
@@ -436,10 +482,10 @@ void MainWindow::setup_ViewMenu_Actions()
         if( Properties::Instance()->scrollBarPos < scrollBarPosition->actions().size() )
             scrollBarPosition->actions().at(Properties::Instance()->scrollBarPos)->setChecked(true);
         connect(scrollBarPosition, &QActionGroup::triggered,
-             consoleTabulator, &TabWidget::changeScrollPosition);
+                consoleTabulator, &TabWidget::changeScrollPosition);
 
     }
-    if (scrollPosMenu == NULL) {
+    if (scrollPosMenu == nullptr) {
         scrollPosMenu = new QMenu(tr("S&crollbar Layout"), menu_Window);
         scrollPosMenu->setObjectName(QStringLiteral("scrollPosMenu"));
 
@@ -451,7 +497,7 @@ void MainWindow::setup_ViewMenu_Actions()
     menu_Window->addMenu(scrollPosMenu);
 
     /* Keyboard cursor shape */
-    if (keyboardCursorShape == NULL) {
+    if (keyboardCursorShape == nullptr) {
         keyboardCursorShape = new QActionGroup(this);
         QAction *block = new QAction(tr("&BlockCursor"), this);
         QAction *underline = new QAction(tr("&UnderlineCursor"), this);
@@ -468,10 +514,10 @@ void MainWindow::setup_ViewMenu_Actions()
             keyboardCursorShape->actions().at(Properties::Instance()->keyboardCursorShape)->setChecked(true);
 
         connect(keyboardCursorShape, &QActionGroup::triggered,
-                 consoleTabulator, &TabWidget::changeKeyboardCursorShape);
+                consoleTabulator, &TabWidget::changeKeyboardCursorShape);
     }
 
-    if (keyboardCursorShapeMenu == NULL) {
+    if (keyboardCursorShapeMenu == nullptr) {
         keyboardCursorShapeMenu = new QMenu(tr("&Keyboard Cursor Shape"), menu_Window);
         keyboardCursorShapeMenu->setObjectName(QStringLiteral("keyboardCursorShapeMenu"));
 
@@ -496,8 +542,7 @@ void MainWindow::on_consoleTabulator_currentChanged(int)
 
 void MainWindow::toggleTabBar()
 {
-    Properties::Instance()->tabBarless
-            = !actions[QLatin1String(SHOW_TAB_BAR)]->isChecked();
+    Properties::Instance()->tabBarless = !actions[QLatin1String(SHOW_TAB_BAR)]->isChecked();
     consoleTabulator->showHideTabBar();
 }
 
@@ -506,8 +551,8 @@ void MainWindow::toggleBorderless()
     setWindowFlags(windowFlags() ^ Qt::FramelessWindowHint);
     show();
     setWindowState(Qt::WindowActive); /* don't loose focus on the window */
-    Properties::Instance()->borderless
-            = actions[QLatin1String(HIDE_WINDOW_BORDERS)]->isChecked(); realign();
+    Properties::Instance()->borderless = actions[QLatin1String(HIDE_WINDOW_BORDERS)]->isChecked();
+    realign();
 }
 
 void MainWindow::toggleMenu()
@@ -539,15 +584,15 @@ void MainWindow::toggleBookmarks()
 void MainWindow::closeEvent(QCloseEvent *ev)
 {
     if (!Properties::Instance()->askOnExit
-            || !consoleTabulator->count())
+        || !consoleTabulator->count())
     {
         // #80 - do not save state and geometry in drop mode
         if (!m_dropMode) {
             if (Properties::Instance()->savePosOnExit) {
-            	Properties::Instance()->mainWindowPosition = pos();
+                Properties::Instance()->mainWindowPosition = pos();
             }
             if (Properties::Instance()->saveSizeOnExit) {
-            	Properties::Instance()->mainWindowSize = size();
+                Properties::Instance()->mainWindowSize = size();
             }
             Properties::Instance()->windowMaximized = isMaximized();
             Properties::Instance()->mainWindowState = saveState();
@@ -624,6 +669,28 @@ void MainWindow::propertiesChanged()
     consoleTabulator->propertiesChanged();
     setDropShortcut(Properties::Instance()->dropShortCut);
 
+
+    const auto menuBarActions = m_menuBar->actions();
+    if (Properties::Instance()->noMenubarAccel)
+    {
+        for (auto& action : menuBarActions)
+        {
+            QString txt = action->text();
+            txt.remove(QRegularExpression(QStringLiteral("\\s*\\(&[a-zA-Z0-9]\\)\\s*"))); // Chinese and Japanese
+            txt.remove(QLatin1Char('&')); // other languages
+            action->setText(txt);
+        }
+    }
+    else if (menubarOrigTexts.size() == menuBarActions.size())
+    {
+        int i = 0;
+        for (auto& action : menuBarActions)
+        {
+            action->setText(menubarOrigTexts.at(i));
+            ++i;
+        }
+    }
+
     m_menuBar->setVisible(Properties::Instance()->menuVisible);
 
     m_bookmarksDock->setVisible(Properties::Instance()->useBookmarks
@@ -648,12 +715,12 @@ void MainWindow::realign()
         QRect geometry = QRect(0, 0,
                                desktop.width()  * Properties::Instance()->dropWidht  / 100,
                                desktop.height() * Properties::Instance()->dropHeight / 100
-                              );
+            );
         geometry.moveCenter(desktop.center());
         // do not use 0 here - we need to calculate with potential panel on top
         geometry.setTop(desktop.top());
         if (geometry != this->geometry()) {
-          setGeometry(geometry);
+            setGeometry(geometry);
         }
     }
 }
@@ -671,9 +738,9 @@ void MainWindow::showHide()
         hide();
     else
     {
-       realign();
-       show();
-       activateWindow();
+        realign();
+        show();
+        activateWindow();
     }
 }
 
@@ -697,6 +764,31 @@ void MainWindow::find()
     consoleTabulator->terminalHolder()->currentTerminal()->impl()->toggleShowSearchBar();
 }
 
+void MainWindow::handleHistory()
+{
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
+    QDir().mkpath(dir);
+    const QString fn = dir + QLatin1String("/qterminal.history.") + QString::number(QCoreApplication::applicationPid());
+    QFile file(fn);
+    if (!file.open(QIODevice::WriteOnly)) {
+        qDebug() << "Failed to open" << file.fileName() << "for writing";
+        return;
+    }
+    TermWidgetImpl *impl = consoleTabulator->terminalHolder()->currentTerminal()->impl();
+    impl->saveHistory(&file);
+    file.close();
+    QStringList args = Properties::Instance()->handleHistoryCommand.split(QLatin1Char(' '), QString::SkipEmptyParts);
+    if (args.isEmpty())
+        return;
+
+    QString command = args[0];
+    args.removeFirst();
+    args << fn;
+    if (!QProcess::startDetached(command, args)) {
+        qDebug() << "Failed to start command" << command << args;
+    }
+
+}
 
 bool MainWindow::event(QEvent *event)
 {
@@ -704,9 +796,9 @@ bool MainWindow::event(QEvent *event)
     {
         if (m_dropMode &&
             !Properties::Instance()->dropKeepOpen &&
-            qApp->activeWindow() == 0
-           )
-           hide();
+            qApp->activeWindow() == nullptr
+            )
+            hide();
     }
     return QMainWindow::event(event);
 }
@@ -760,30 +852,43 @@ void MainWindow::onCurrentTitleChanged(int index)
     setWindowIcon(icon.isNull() || !Properties::Instance()->changeWindowIcon ? QIcon::fromTheme(QStringLiteral("utilities-terminal")) : icon);
 }
 
-bool MainWindow::hasMultipleTabs()
+bool MainWindow::hasMultipleTabs(QAction *)
 {
     return consoleTabulator->findChildren<TermWidgetHolder*>().count() > 1;
 }
 
-bool MainWindow::hasMultipleSubterminals()
+bool MainWindow::hasMultipleSubterminals(QAction *)
 {
     return consoleTabulator->terminalHolder()->findChildren<TermWidget*>().count() > 1;
 }
 
-void MainWindow::updateDisabledActions()
+bool MainWindow::hasIndexedTab(QAction *action)
 {
-    const QList<QAction*> actions = menu_Actions->actions();
-    for (QAction *action : actions) {
-        if (!action->data().isNull()) {
-            const checkfn check = action->data().value<checkfn>();
-            action->setEnabled(check(*this));
-        }
-    }
+    bool ok;
+    const int index = action->property("tab").toInt(&ok);
+    Q_ASSERT(ok);
+    static_cast<void>(ok);
+    return consoleTabulator->findChildren<TermWidgetHolder*>().count() >= index;
 }
 
+void MainWindow::updateDisabledActions()
+{
+    std::function<void(const QList<QAction *> &)> enableActions = [this, &enableActions](const QList<QAction *> &actions) {
+        for (QAction *action : actions) {
+            if (!action->data().isNull()) {
+                const checkfn check = action->data().value<checkfn>();
+                action->setEnabled(check(*this, action));
+            } else if (QMenu *menu = action->menu()) {
+                enableActions(menu->actions());
+            }
+        }
+    };
+
+    enableActions(menu_Actions->actions());
+}
 
 QMap< QString, QAction * >& MainWindow::leaseActions() {
-        return actions;
+    return actions;
 }
 #ifdef HAVE_QDBUS
 
