@@ -38,8 +38,8 @@ class MainWindow : public QMainWindow, private Ui::mainWindow, public DBusAddres
 public:
     MainWindow(TerminalConfig& cfg,
                bool dropMode,
-               QWidget * parent = 0, Qt::WindowFlags f = 0);
-    ~MainWindow();
+               QWidget * parent = nullptr, Qt::WindowFlags f = nullptr);
+    ~MainWindow() override;
 
     bool dropMode() { return m_dropMode; }
     QMap<QString, QAction*> & leaseActions();
@@ -52,7 +52,7 @@ public:
     #endif
 
 protected:
-     bool event(QEvent* event);
+     bool event(QEvent* event) override;
 
 private:
     QActionGroup *tabPosition, *scrollBarPosition, *keyboardCursorShape;
@@ -69,9 +69,11 @@ private:
     QDockWidget *m_bookmarksDock;
 
     void setup_Action(const char *name, QAction *action, const char *defaultShortcut, const QObject *receiver,
-                      const char *slot, QMenu *menu = NULL, const QVariant &data = QVariant());
+                      const char *slot, QMenu *menu = nullptr, const QVariant &data = QVariant());
     QMap< QString, QAction * > actions;
-    
+
+    QStringList menubarOrigTexts;
+
     void rebuildActions();
 
     void setup_FileMenu_Actions();
@@ -80,7 +82,7 @@ private:
     void setup_ContextMenu_Actions();
     void setupCustomDirs();
 
-    void closeEvent(QCloseEvent*);
+    void closeEvent(QCloseEvent*) override;
 
     void enableDropMode();
     QToolButton *m_dropLockButton;
@@ -89,8 +91,9 @@ private:
     void realign();
     void setDropShortcut(QKeySequence dropShortCut);
 
-    bool hasMultipleTabs();
-    bool hasMultipleSubterminals();
+    bool hasMultipleTabs(QAction *);
+    bool hasMultipleSubterminals(QAction *);
+    bool hasIndexedTab(QAction *action);
 
 public slots:
     void showHide();
@@ -119,5 +122,6 @@ private slots:
     void addNewTab();
     void onCurrentTitleChanged(int index);
 
+    void handleHistory();
 };
 #endif //MAINWINDOW_H
