@@ -21,6 +21,8 @@
 #include <QDebug>
 #include <QStyleFactory>
 #include <QFileDialog>
+#include <QScreen>
+#include <QWindow>
 
 #include "propertiesdialog.h"
 #include "properties.h"
@@ -72,12 +74,54 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     connect(chooseBackgroundImageButton, &QPushButton::clicked,
             this, &PropertiesDialog::chooseBackgroundImageButton_clicked);
 
+    // fixed size
+    connect(saveSizeOnExitCheckBox, &QCheckBox::stateChanged, [this] (int state) {
+        fixedSizeLabel->setEnabled(state == Qt::Unchecked);
+        xLabel->setEnabled(state == Qt::Unchecked);
+        fixedWithSpinBox->setEnabled(state == Qt::Unchecked);
+        fixedHeightSpinBox->setEnabled(state == Qt::Unchecked);
+        getCurrentSizeButton->setEnabled(state == Qt::Unchecked);
+    });
+    connect(getCurrentSizeButton, &QAbstractButton::clicked, [this, parent] {
+        if (parent != nullptr)
+        {
+            QSize pSize = parent->window()->geometry().size();
+            fixedWithSpinBox->setValue(pSize.width());
+            fixedHeightSpinBox->setValue(pSize.height());
+        }
+    });
+    QSize ag;
+    QSize minWinSize(0, 0);
+    if (parent != nullptr)
+    {
+        minWinSize = parent->minimumSize();
+        if (QWindow *win = parent->windowHandle())
+        {
+            if (QScreen *sc = win->screen())
+            {
+                ag = sc->availableVirtualGeometry().size()
+                     // also consider the parent frame thickness because the parent window is fully formed
+                     - (parent->window()->frameGeometry().size()
+                        - parent->window()->geometry().size());
+            }
+        }
+    }
+    fixedWithSpinBox->setMinimum(minWinSize.width());
+    fixedHeightSpinBox->setMinimum(minWinSize.height());
+    if (!ag.isEmpty())
+    {
+        fixedWithSpinBox->setMaximum(qMax(ag.width(), minWinSize.width()));
+        fixedHeightSpinBox->setMaximum(qMax(ag.height() , minWinSize.height()));
+    }
+
     QStringList emulations = QTermWidget::availableKeyBindings();
     QStringList colorSchemes = QTermWidget::availableColorSchemes();
     colorSchemes.sort(Qt::CaseInsensitive);
 
     listWidget->setCurrentRow(0);
-    listWidget->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContentsOnFirstShow);
+    // resize the list widget to its content
+    listWidget->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+    listWidget->setMaximumWidth(listWidget->sizeHintForColumn(0) + 2 * listWidget->frameWidth() + 4);
 
     colorSchemaCombo->addItems(colorSchemes);
     int csix = colorSchemaCombo->findText(Properties::Instance()->colorScheme);
@@ -121,9 +165,12 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
 
     hideTabBarCheckBox->setChecked(Properties::Instance()->hideTabBarWithOneTab);
 
-    // show main menu bar
+    // main menu bar
+    menuAccelCheckBox->setChecked(Properties::Instance()->noMenubarAccel);
     showMenuCheckBox->setChecked(Properties::Instance()->menuVisible);
 
+    borderlessCheckBox->setChecked(Properties::Instance()->borderless);
+
     /* actions by motion after paste */
 
     QStringList motionAfter;
@@ -155,11 +202,15 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
 
     savePosOnExitCheckBox->setChecked(Properties::Instance()->savePosOnExit);
     saveSizeOnExitCheckBox->setChecked(Properties::Instance()->saveSizeOnExit);
+    fixedWithSpinBox->setValue(Properties::Instance()->fixedWindowSize.width());
+    fixedHeightSpinBox->setValue(Properties::Instance()->fixedWindowSize.height());
 
     useCwdCheckBox->setChecked(Properties::Instance()->useCWD);
 
     termComboBox->setCurrentText(Properties::Instance()->term);
 
+    handleHistoryLineEdit->setText(Properties::Instance()->handleHistoryCommand);
+
     historyLimited->setChecked(Properties::Instance()->historyLimited);
     historyUnlimited->setChecked(!Properties::Instance()->historyLimited);
     historyLimitedTo->setValue(Properties::Instance()->historyLimitedTo);
@@ -184,11 +235,27 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     changeWindowTitleCheckBox->setChecked(Properties::Instance()->changeWindowTitle);
     changeWindowIconCheckBox->setChecked(Properties::Instance()->changeWindowIcon);
     enabledBidiSupportCheckBox->setChecked(Properties::Instance()->enabledBidiSupport);
+    useFontBoxDrawingCharsCheckBox->setChecked(Properties::Instance()->useFontBoxDrawingChars);
 
     trimPastedTrailingNewlinesCheckBox->setChecked(Properties::Instance()->trimPastedTrailingNewlines);
     confirmMultilinePasteCheckBox->setChecked(Properties::Instance()->confirmMultilinePaste);
 
-    resize(sizeHint()); // show it compact but not too much
+    // save the size on canceling too (it's saved on accepting by apply())
+    connect(this, &QDialog::rejected, [this] {
+        Properties::Instance()->prefDialogSize = size();
+        Properties::Instance()->saveSettings();
+    });
+
+    // restore its size while fitting it into available desktop geometry
+    QSize s;
+    if (!Properties::Instance()->prefDialogSize.isEmpty())
+        s = Properties::Instance()->prefDialogSize;
+    else
+        s = size(); // fall back to the ui size
+    if (!ag.isEmpty())
+        resize(s.boundedTo(ag));
+    else // never happens
+        resize(s);
 }
 
 
@@ -227,10 +294,13 @@ void PropertiesDialog::apply()
 
     Properties::Instance()->savePosOnExit = savePosOnExitCheckBox->isChecked();
     Properties::Instance()->saveSizeOnExit = saveSizeOnExitCheckBox->isChecked();
+    Properties::Instance()->fixedWindowSize = QSize(fixedWithSpinBox->value(), fixedHeightSpinBox->value()).expandedTo(QSize(300, 200)); // FIXME: make Properties variables private and use public methods for setting/getting them
+    Properties::Instance()->prefDialogSize = size();
 
     Properties::Instance()->useCWD = useCwdCheckBox->isChecked();
 
     Properties::Instance()->term = termComboBox->currentText();
+    Properties::Instance()->handleHistoryCommand = handleHistoryLineEdit->text();
 
     Properties::Instance()->scrollBarPos = scrollBarPos_comboBox->currentIndex();
     Properties::Instance()->tabsPos = tabsPos_comboBox->currentIndex();
@@ -239,7 +309,9 @@ void PropertiesDialog::apply()
     Properties::Instance()->keyboardCursorShape = keybCursorShape_comboBox->currentIndex();
     Properties::Instance()->showCloseTabButton = closeTabButtonCheckBox->isChecked();
     Properties::Instance()->hideTabBarWithOneTab = hideTabBarCheckBox->isChecked();
+    Properties::Instance()->noMenubarAccel = menuAccelCheckBox->isChecked();
     Properties::Instance()->menuVisible = showMenuCheckBox->isChecked();
+    Properties::Instance()->borderless = borderlessCheckBox->isChecked();
     Properties::Instance()->m_motionAfterPaste = motionAfterPasting_comboBox->currentIndex();
 
     Properties::Instance()->historyLimited = historyLimited->isChecked();
@@ -263,6 +335,7 @@ void PropertiesDialog::apply()
     Properties::Instance()->changeWindowTitle = changeWindowTitleCheckBox->isChecked();
     Properties::Instance()->changeWindowIcon = changeWindowIconCheckBox->isChecked();
     Properties::Instance()->enabledBidiSupport = enabledBidiSupportCheckBox->isChecked();
+    Properties::Instance()->useFontBoxDrawingChars = useFontBoxDrawingCharsCheckBox->isChecked();
 
     Properties::Instance()->trimPastedTrailingNewlines = trimPastedTrailingNewlinesCheckBox->isChecked();
     Properties::Instance()->confirmMultilinePaste = confirmMultilinePasteCheckBox->isChecked();
@@ -357,7 +430,7 @@ void PropertiesDialog::setupShortcuts()
 void PropertiesDialog::bookmarksButton_clicked()
 {
     QFileDialog dia(this, tr("Open or create bookmarks file"));
-    dia.setConfirmOverwrite(false);
+    dia.setOption(QFileDialog::DontConfirmOverwrite, true);
     dia.setFileMode(QFileDialog::AnyFile);
     if (!dia.exec())
         return;
