@@ -41,12 +41,12 @@ class Delegate : public QStyledItemDelegate
     Q_OBJECT
 
 public:
-    Delegate (QObject *parent = 0);
+    Delegate (QObject *parent = nullptr);
 
-    virtual QWidget* createEditor(QWidget *parent,
+    QWidget* createEditor(QWidget *parent,
                                   const QStyleOptionViewItem&,
-                                  const QModelIndex&) const;
-    virtual bool eventFilter(QObject *object, QEvent *event);
+                                  const QModelIndex&) const override;
+    bool eventFilter(QObject *object, QEvent *event) override;
 };
 
 class PropertiesDialog : public QDialog, Ui::PropertiesDialog
@@ -56,8 +56,8 @@ class PropertiesDialog : public QDialog, Ui::PropertiesDialog
     QString oldAccelText; // Placeholder when editing shortcut
 
     public:
-        PropertiesDialog(QWidget *parent=NULL);
-        ~PropertiesDialog();
+        PropertiesDialog(QWidget *parent=nullptr);
+        ~PropertiesDialog() override;
 
     signals:
         void propertiesChanged();
@@ -69,7 +69,7 @@ class PropertiesDialog : public QDialog, Ui::PropertiesDialog
 
     private slots:
         void apply();
-        void accept();
+        void accept() override;
 
         void changeFontButton_clicked();
         void chooseBackgroundImageButton_clicked();
