@@ -23,7 +23,7 @@
 #include <QMessageBox>
 #include <QAbstractButton>
 #include <QMouseEvent>
-#include <assert.h>
+#include <cassert>
 
 #ifdef HAVE_QDBUS
     #include <QtDBus/QtDBus>
@@ -53,16 +53,14 @@ TermWidgetImpl::TermWidgetImpl(TerminalConfig &cfg, QWidget * parent)
 
     propertiesChanged();
 
-    setHistorySize(5000);
-
     setWorkingDirectory(cfg.getWorkingDirectory());
 
     QString shell = cfg.getShell();
     if (!shell.isEmpty())
     {
-        qDebug() << "Shell program:" << shell;
+        //qDebug() << "Shell program:" << shell;
         QStringList parts = shell.split(QRegExp(QStringLiteral("\\s+")), QString::SkipEmptyParts);
-        qDebug() << parts;
+        //qDebug() << parts;
         setShellProgram(parts.at(0));
         parts.removeAt(0);
         if (parts.count())
@@ -102,6 +100,7 @@ void TermWidgetImpl::propertiesChanged()
     setTerminalOpacity(1.0 - Properties::Instance()->termTransparency/100.0);
     setTerminalBackgroundImage(Properties::Instance()->backgroundImage);
     setBidiEnabled(Properties::Instance()->enabledBidiSupport);
+    setDrawLineChars(!Properties::Instance()->useFontBoxDrawingChars);
 
     /* be consequent with qtermwidget.h here */
     switch(Properties::Instance()->scrollBarPos) {
@@ -163,6 +162,7 @@ void TermWidgetImpl::customContextMenuCall(const QPoint & pos)
     menu.addAction(actions[QStringLiteral(SUB_COLLAPSE)]);
     menu.addSeparator();
     menu.addAction(actions[QStringLiteral(TOGGLE_MENU)]);
+    menu.addAction(actions[QStringLiteral(HIDE_WINDOW_BORDERS)]);
     menu.addAction(actions[QStringLiteral(PREFERENCES)]);
     menu.exec(mapToGlobal(pos));
 }
@@ -344,7 +344,7 @@ void TermWidget::paintEvent (QPaintEvent *)
 QDBusObjectPath TermWidget::splitHorizontal(const QHash<QString,QVariant> &termArgs)
 {
     TermWidgetHolder *holder = findParent<TermWidgetHolder>(this);
-    assert(holder != NULL);
+    assert(holder != nullptr);
     TerminalConfig cfg = TerminalConfig::fromDbus(termArgs, this);
     return holder->split(this, Qt::Horizontal, cfg)->getDbusPath();
 }
@@ -352,7 +352,7 @@ QDBusObjectPath TermWidget::splitHorizontal(const QHash<QString,QVariant> &termA
 QDBusObjectPath TermWidget::splitVertical(const QHash<QString,QVariant> &termArgs)
 {
     TermWidgetHolder *holder = findParent<TermWidgetHolder>(this);
-    assert(holder != NULL);
+    assert(holder != nullptr);
     TerminalConfig cfg = TerminalConfig::fromDbus(termArgs, this);
     return holder->split(this, Qt::Vertical, cfg)->getDbusPath();
 }
