@@ -36,284 +36,294 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="79"/>
+        <location filename="../mainwindow.cpp" line="90"/>
         <source>Bookmarks</source>
         <translation>סימניות</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="190"/>
         <source>Press &quot;%1&quot; to see the terminal.</source>
         <translation>לחיצה על „%1” כדי לצפות במסוף.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="219"/>
+        <location filename="../mainwindow.cpp" line="239"/>
         <source>&amp;Next Tab</source>
         <translation>הלשונית ה&amp;באה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="222"/>
+        <location filename="../mainwindow.cpp" line="242"/>
         <source>&amp;Previous Tab</source>
         <translation>הלשונית ה&amp;קודמת</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="231"/>
+        <location filename="../mainwindow.cpp" line="251"/>
         <source>Move Tab &amp;Left</source>
         <translation>העברת לשונית &amp;שמאלה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="234"/>
+        <location filename="../mainwindow.cpp" line="254"/>
         <source>Move Tab &amp;Right</source>
         <translation>העברת לשונית ימי&amp;נה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="239"/>
+        <location filename="../mainwindow.cpp" line="273"/>
         <source>Split Terminal &amp;Horizontally</source>
         <translation>פיצול המסוף או&amp;פקית</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="242"/>
+        <location filename="../mainwindow.cpp" line="276"/>
         <source>Split Terminal &amp;Vertically</source>
         <translation>פיצול המסוף א&amp;נכית</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="247"/>
+        <location filename="../mainwindow.cpp" line="281"/>
         <source>&amp;Collapse Subterminal</source>
         <translation>&amp;צמצום תת־מסוף</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="212"/>
+        <location filename="../mainwindow.cpp" line="232"/>
         <source>&amp;Clear Active Terminal</source>
         <translation>מ&amp;חיקת תוכן המסוף הפעיל</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="225"/>
+        <location filename="../mainwindow.cpp" line="245"/>
         <source>&amp;Previous Tab in History</source>
         <translation>הלשונית ה&amp;קודמת בהיסטוריה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="228"/>
+        <location filename="../mainwindow.cpp" line="248"/>
         <source>&amp;Next Tab in History</source>
         <translation>הלשונית ה&amp;באה בהיסטוריה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="250"/>
+        <location filename="../mainwindow.cpp" line="259"/>
+        <source>Tab</source>
+        <translation>לשונית</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="260"/>
+        <source>Go to</source>
+        <translation>מעבר אל</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="284"/>
         <source>&amp;Top Subterminal</source>
         <translation>תת־מסוף &amp;עליון</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="253"/>
+        <location filename="../mainwindow.cpp" line="287"/>
         <source>&amp;Bottom Subterminal</source>
         <translation>תת־מסוף &amp;תחתון</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="256"/>
+        <location filename="../mainwindow.cpp" line="290"/>
         <source>L&amp;eft Subterminal</source>
         <translation>תת־מסוף &amp;שמאלי</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="259"/>
+        <location filename="../mainwindow.cpp" line="293"/>
         <source>R&amp;ight Subterminal</source>
         <translation>תת־מסוף ימ&amp;ני</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="266"/>
+        <location filename="../mainwindow.cpp" line="300"/>
         <source>Copy &amp;Selection</source>
         <translation>העתקת ה&amp;בחירה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="269"/>
+        <location filename="../mainwindow.cpp" line="303"/>
         <source>Paste Clip&amp;board</source>
         <translation>הדבקת לוח הג&amp;זירים</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="272"/>
+        <location filename="../mainwindow.cpp" line="306"/>
         <source>Paste S&amp;election</source>
         <translation>הדבקת הב&amp;חירה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="275"/>
+        <location filename="../mainwindow.cpp" line="309"/>
         <source>Zoom &amp;in</source>
         <translation>הת&amp;קרבות</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="278"/>
+        <location filename="../mainwindow.cpp" line="312"/>
         <source>Zoom &amp;out</source>
         <translation>הת&amp;רחקות</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="281"/>
+        <location filename="../mainwindow.cpp" line="315"/>
         <source>Zoom rese&amp;t</source>
         <translation>&amp;איפוס התקריב</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="286"/>
+        <location filename="../mainwindow.cpp" line="320"/>
         <source>&amp;Find...</source>
         <translation>חי&amp;פוש…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="294"/>
+        <location filename="../mainwindow.cpp" line="328"/>
         <source>&amp;Save Session</source>
         <translation>&amp;שמירת ההפעלה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="300"/>
+        <location filename="../mainwindow.cpp" line="334"/>
         <source>&amp;Load Session</source>
         <translation>&amp;טעינת הפעלה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="307"/>
+        <location filename="../mainwindow.cpp" line="341"/>
         <source>&amp;Toggle Menu</source>
         <translation>ה&amp;חלפת מצב תפריט</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="312"/>
+        <location filename="../mainwindow.cpp" line="346"/>
         <source>Rename session</source>
         <translation>שינוי שם הפעלה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="320"/>
+        <location filename="../mainwindow.cpp" line="355"/>
         <source>&amp;New Tab</source>
         <translation>&amp;לשונית חדשה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="359"/>
         <source>New Tab From &amp;Preset</source>
         <translation>לשונית חדשה מ&amp;ערכה מוגדרת</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="325"/>
+        <location filename="../mainwindow.cpp" line="360"/>
         <source>1 &amp;Terminal</source>
         <translation>מסוף &amp;1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="327"/>
+        <location filename="../mainwindow.cpp" line="362"/>
         <source>2 &amp;Horizontal Terminals</source>
         <translation>2 מסופים או&amp;פקיים</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="329"/>
+        <location filename="../mainwindow.cpp" line="364"/>
         <source>2 &amp;Vertical Terminals</source>
         <translation>2 מסופים א&amp;נכיים</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="331"/>
+        <location filename="../mainwindow.cpp" line="366"/>
         <source>4 Terminal&amp;s</source>
         <translation>4 מ&amp;סופים</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="337"/>
+        <location filename="../mainwindow.cpp" line="372"/>
         <source>&amp;Close Tab</source>
         <translation>ס&amp;גירת לשונית</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="340"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>&amp;New Window</source>
         <translation>&amp;חלון חדש</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="380"/>
         <source>&amp;Preferences...</source>
         <translation>ה&amp;עדפות…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="349"/>
+        <location filename="../mainwindow.cpp" line="384"/>
         <source>&amp;Quit</source>
         <translation>י&amp;ציאה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="355"/>
+        <location filename="../mainwindow.cpp" line="390"/>
         <source>&amp;Hide Window Borders</source>
         <translation>הסתרת &amp;גבולות החלון</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="366"/>
+        <location filename="../mainwindow.cpp" line="401"/>
         <source>&amp;Show Tab Bar</source>
         <translation>הצגת ס&amp;רגל לשוניות</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../mainwindow.cpp" line="409"/>
         <source>Fullscreen</source>
         <translation>מסך מלא</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="380"/>
+        <location filename="../mainwindow.cpp" line="415"/>
         <source>Toggle Bookmarks</source>
         <translation>החלפת הצגת לשוניות</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="388"/>
+        <location filename="../mainwindow.cpp" line="423"/>
         <source>&amp;Bottom</source>
         <translation>ת&amp;חתון</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="389"/>
+        <location filename="../mainwindow.cpp" line="424"/>
         <source>&amp;Top</source>
         <translation>&amp;עליון</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="390"/>
-        <location filename="../mainwindow.cpp" line="426"/>
+        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="../mainwindow.cpp" line="461"/>
         <source>&amp;Right</source>
         <translation>י&amp;מין</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="391"/>
-        <location filename="../mainwindow.cpp" line="427"/>
+        <location filename="../mainwindow.cpp" line="426"/>
+        <location filename="../mainwindow.cpp" line="462"/>
         <source>&amp;Left</source>
         <translation>&amp;שמאל</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="409"/>
+        <location filename="../mainwindow.cpp" line="444"/>
         <source>&amp;Tabs Layout</source>
         <translation>&amp;פריסת לשוניות</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="../mainwindow.cpp" line="460"/>
         <source>&amp;None</source>
         <translation>&amp;ללא</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="443"/>
+        <location filename="../mainwindow.cpp" line="478"/>
         <source>S&amp;crollbar Layout</source>
         <translation>פריסת סרגל &amp;גלילה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="456"/>
+        <location filename="../mainwindow.cpp" line="491"/>
         <source>&amp;BlockCursor</source>
         <translation>סמן מ&amp;רובע</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="457"/>
+        <location filename="../mainwindow.cpp" line="492"/>
         <source>&amp;UnderlineCursor</source>
         <translation>סמן &amp;קו תחתי</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="458"/>
+        <location filename="../mainwindow.cpp" line="493"/>
         <source>&amp;IBeamCursor</source>
         <translation>סמן קור&amp;ת I</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="475"/>
+        <location filename="../mainwindow.cpp" line="510"/>
         <source>&amp;Keyboard Cursor Shape</source>
         <translation>&amp;צורת סמן המקלדת</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="566"/>
+        <location filename="../mainwindow.cpp" line="599"/>
         <source>Exit QTerminal</source>
         <translation>יציאה מ־QTerminal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="568"/>
+        <location filename="../mainwindow.cpp" line="601"/>
         <source>Do not ask again</source>
         <translation>לא לשאול שוב</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="576"/>
+        <location filename="../mainwindow.cpp" line="609"/>
         <source>Are you sure you want to exit?</source>
         <translation>לצאת?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="607"/>
+        <location filename="../mainwindow.cpp" line="640"/>
         <source>A lightweight multiplatform terminal emulator</source>
         <translation>מדמה מסוף קליל במשאבים שמיועד למגוון פלטפורמות</translation>
     </message>
@@ -326,374 +336,405 @@
         <translation>הגדרות מסוף</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="52"/>
+        <location filename="../forms/propertiesdialog.ui" line="31"/>
         <source>Appearance</source>
         <translation>מראה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="57"/>
-        <location filename="../forms/propertiesdialog.ui" line="474"/>
+        <location filename="../forms/propertiesdialog.ui" line="39"/>
+        <location filename="../forms/propertiesdialog.ui" line="555"/>
         <source>Behavior</source>
         <translation>התנהגות</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="62"/>
+        <location filename="../forms/propertiesdialog.ui" line="47"/>
         <source>Shortcuts</source>
         <translation>קיצורי דרך</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="67"/>
+        <location filename="../forms/propertiesdialog.ui" line="55"/>
         <source>Dropdown</source>
         <translation>תפריט נפתח</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="72"/>
+        <location filename="../forms/propertiesdialog.ui" line="63"/>
         <source>Bookmarks</source>
         <translation>סימניות</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="90"/>
+        <location filename="../forms/propertiesdialog.ui" line="258"/>
         <source>Hide tab bar with only one tab</source>
         <translation>הסתרת סרגל הלשוניות כשיש לשונית אחת בלבד</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="100"/>
+        <location filename="../forms/propertiesdialog.ui" line="275"/>
         <source>Color scheme</source>
         <translation>ערכת צבעים</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="110"/>
+        <location filename="../forms/propertiesdialog.ui" line="335"/>
         <source>Scrollbar position</source>
         <translation>מיקום סרגל הגלילה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="120"/>
+        <location filename="../forms/propertiesdialog.ui" line="204"/>
         <source>Start with preset:</source>
         <translation>התחלה עם ערכה מוגדרת:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="136"/>
+        <location filename="../forms/propertiesdialog.ui" line="368"/>
         <source>Show a border around the current terminal</source>
         <translation>הצגת מסגרת סביב המסוף הנוכחי</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="143"/>
+        <location filename="../forms/propertiesdialog.ui" line="345"/>
         <source>Terminal transparency</source>
         <translation>שקיפות מסוף</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="153"/>
+        <location filename="../forms/propertiesdialog.ui" line="358"/>
         <source>Application transparency</source>
         <translation>שקיפות היישום</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="164"/>
+        <location filename="../forms/propertiesdialog.ui" line="215"/>
         <source>None (single terminal)</source>
         <translation>ללא (מסוף בודד)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="169"/>
+        <location filename="../forms/propertiesdialog.ui" line="220"/>
         <source>2 terminals horizontally</source>
         <translation>2 מסופים אופקית</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="174"/>
+        <location filename="../forms/propertiesdialog.ui" line="225"/>
         <source>2 terminals vertically</source>
         <translation>2 מסופים אנכית</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="179"/>
+        <location filename="../forms/propertiesdialog.ui" line="230"/>
         <source>4 terminals</source>
         <translation>4 מסופים</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="187"/>
-        <location filename="../forms/propertiesdialog.ui" line="280"/>
+        <location filename="../forms/propertiesdialog.ui" line="117"/>
+        <location filename="../forms/propertiesdialog.ui" line="389"/>
         <source> %</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="218"/>
+        <location filename="../forms/propertiesdialog.ui" line="148"/>
         <source>Font</source>
         <translation>גופן</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="254"/>
+        <location filename="../forms/propertiesdialog.ui" line="184"/>
         <source>&amp;Change...</source>
         <translation>&amp;שינוי…</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="267"/>
+        <location filename="../forms/propertiesdialog.ui" line="418"/>
         <source>Tabs position</source>
         <translation>מיקום לשוניות</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="296"/>
+        <location filename="../forms/propertiesdialog.ui" line="238"/>
         <source>Widget style</source>
         <translation>סגנון וידג׳ט</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="319"/>
+        <location filename="../forms/propertiesdialog.ui" line="194"/>
         <source>Show the menu bar</source>
         <translation>הצגת סרגל התפריטים</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="326"/>
+        <location filename="../forms/propertiesdialog.ui" line="299"/>
         <source>Cursor shape</source>
-        <translation type="unfinished"></translation>
+        <translation>צורת סמן</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="336"/>
+        <location filename="../forms/propertiesdialog.ui" line="428"/>
         <source>Change window title based on current terminal</source>
         <translation>החלפת כותרת החלון על בסיס המסוף הנוכחי</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="343"/>
+        <location filename="../forms/propertiesdialog.ui" line="445"/>
         <source>Change window icon based on current terminal</source>
         <translation>החלפת סמל החלון על בסיס המסוף הנוכחי</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="350"/>
+        <location filename="../forms/propertiesdialog.ui" line="382"/>
         <source>Enable bi-directional text support</source>
         <translation>הפעלת תמיכה בטקסט דו־כיווני (עברית)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="357"/>
+        <location filename="../forms/propertiesdialog.ui" line="265"/>
         <source>Background image:</source>
         <translation>תמונת רקע:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="369"/>
+        <location filename="../forms/propertiesdialog.ui" line="290"/>
         <source>Select</source>
         <translation>בחירה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="378"/>
+        <location filename="../forms/propertiesdialog.ui" line="452"/>
         <source>Show terminal size on resize</source>
         <translation>הצגת גודל המסוף עם שינוי הגודל</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="385"/>
+        <location filename="../forms/propertiesdialog.ui" line="435"/>
         <source>Fixed tab width:</source>
         <translation>רוחב לשונית קבוע:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="395"/>
-        <location filename="../forms/propertiesdialog.ui" line="425"/>
+        <location filename="../forms/propertiesdialog.ui" line="375"/>
+        <location filename="../forms/propertiesdialog.ui" line="408"/>
         <source>px</source>
         <translation>פיקסלים</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="405"/>
+        <location filename="../forms/propertiesdialog.ui" line="325"/>
         <source>Show close button on each tab</source>
         <translation>הצגת כפתור סגירה על כל לשונית</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="415"/>
+        <location filename="../forms/propertiesdialog.ui" line="248"/>
         <source>Terminal margin</source>
-        <translation type="unfinished"></translation>
+        <translation>גבול מסוף</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="449"/>
+        <location filename="../forms/propertiesdialog.ui" line="459"/>
+        <source>Use box drawing characters contained in the font</source>
+        <translation>להשתמש בתווי תיבה שנכללים בגופן</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="466"/>
+        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
+        <translation>מקשי האצה מופעלים עם Alt ויכולים לשבש את פעילות המסוף.</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="469"/>
+        <source>No menu bar accelerator</source>
+        <translation>אין מאיץ לסרגל התפריטים</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="530"/>
         <source>Emulation</source>
         <translation>הדמיה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="458"/>
+        <location filename="../forms/propertiesdialog.ui" line="539"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;איזו התנהגות לדמות. הגדרה זו אינה חייבת להתאים למערכת ההפעלה שלך.&lt;/p&gt;&lt;p&gt;הדמיית &lt;span style=&quot; font-weight:600;&quot;&gt;בררת המחדל&lt;/span&gt; היא עתודה עם ערכת תכונות מצומצמת.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="480"/>
+        <location filename="../forms/propertiesdialog.ui" line="561"/>
         <source>Action after paste</source>
         <translation>פעולה לאחר הדבקה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="490"/>
+        <location filename="../forms/propertiesdialog.ui" line="571"/>
         <source>Confirm multiline paste</source>
         <translation>בקשת אישור להדבקה של מספר שורות</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="497"/>
+        <location filename="../forms/propertiesdialog.ui" line="578"/>
         <source>Trim trailing newlines in pasted text</source>
         <translation>חיתוך שורות חדשות מקדימות בטקסט שמודבק</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="530"/>
+        <location filename="../forms/propertiesdialog.ui" line="598"/>
         <source>Open new terminals in current working directory</source>
         <translation>פתיחת מסופים חדשים בתיקיית העבודה הנוכחית</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="537"/>
+        <location filename="../forms/propertiesdialog.ui" line="605"/>
         <source>Save Size when closing</source>
         <translation>שמירת הגודל עם הסגירה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="544"/>
+        <location filename="../forms/propertiesdialog.ui" line="612"/>
         <source>Save Position when closing</source>
         <translation>שמירת המיקום בעת הסגירה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="551"/>
+        <location filename="../forms/propertiesdialog.ui" line="619"/>
         <source>Ask for confirmation when closing</source>
         <translation>לבקש אישור בעת סגירה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="561"/>
+        <location filename="../forms/propertiesdialog.ui" line="629"/>
         <source>Unlimited history</source>
         <translation>היסטוריה בלתי מוגבלת</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="568"/>
+        <location filename="../forms/propertiesdialog.ui" line="636"/>
         <source>History size (in lines)</source>
         <translation>גודל ההיסטוריה (בשורות)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="575"/>
+        <location filename="../forms/propertiesdialog.ui" line="643"/>
         <source>Default $TERM</source>
         <translation>$TERM כבררת מחדל</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="631"/>
+        <location filename="../forms/propertiesdialog.ui" line="681"/>
+        <source>Start with this size:</source>
+        <translation>התחלה עם הגודל הזה:</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="688"/>
+        <location filename="../forms/propertiesdialog.ui" line="702"/>
+        <source> px</source>
+        <translation> פיקסלים</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="709"/>
+        <source>Get current size</source>
+        <translation>קבלת הגודל הנוכחי</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="767"/>
         <source>Shortcut</source>
         <translation>קיצור דרך</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="636"/>
+        <location filename="../forms/propertiesdialog.ui" line="772"/>
         <source>Key</source>
         <translation>מקש</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="648"/>
+        <location filename="../forms/propertiesdialog.ui" line="784"/>
         <source>Show on start</source>
         <translation>הצגה בהתחלה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="655"/>
+        <location filename="../forms/propertiesdialog.ui" line="791"/>
         <source>Size</source>
         <translation>גודל</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="666"/>
+        <location filename="../forms/propertiesdialog.ui" line="802"/>
         <source>Height</source>
         <translation>גובה</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="676"/>
-        <location filename="../forms/propertiesdialog.ui" line="693"/>
+        <location filename="../forms/propertiesdialog.ui" line="812"/>
+        <location filename="../forms/propertiesdialog.ui" line="829"/>
         <source>%</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="683"/>
+        <location filename="../forms/propertiesdialog.ui" line="819"/>
         <source>Width</source>
         <translation>רוחב</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="707"/>
+        <location filename="../forms/propertiesdialog.ui" line="843"/>
         <source>Shortcut:</source>
         <translation>קיצור דרך:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="739"/>
+        <location filename="../forms/propertiesdialog.ui" line="875"/>
         <source>Edit bookmark file contents</source>
         <translation>עריכת תכני קובץ סימניות</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="761"/>
+        <location filename="../forms/propertiesdialog.ui" line="897"/>
         <source>Enable bookmarks</source>
         <translation>הפעלת סימניות</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="770"/>
+        <location filename="../forms/propertiesdialog.ui" line="906"/>
         <source>Bookmark file</source>
         <translation>הוספת סימנייה לקובץ</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="783"/>
+        <location filename="../forms/propertiesdialog.ui" line="919"/>
         <source>Find...</source>
         <translation>חיפוש…</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="792"/>
+        <location filename="../forms/propertiesdialog.ui" line="928"/>
         <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
         <translation>באפשרותך לציין מיקום משלך לקובץ סימניות. הגדרה זו מאפשרת לך לשתף סימניות בקלות עם כלים כגון OwnCloud או Dropbox.</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="101"/>
+        <location filename="../propertiesdialog.cpp" line="145"/>
         <source>No scrollbar</source>
         <translation>ללא סרגל גלילה</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="101"/>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="145"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Left</source>
         <translation>שמאל</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="101"/>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="145"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Right</source>
         <translation>ימין</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Top</source>
         <translation>עליון</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Bottom</source>
         <translation>תחתון</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="118"/>
+        <location filename="../propertiesdialog.cpp" line="162"/>
         <source>BlockCursor</source>
         <translation>סמן מרובע</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="118"/>
+        <location filename="../propertiesdialog.cpp" line="162"/>
         <source>UnderlineCursor</source>
         <translation>סמן קו תחתי</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="118"/>
+        <location filename="../propertiesdialog.cpp" line="162"/>
         <source>IBeamCursor</source>
         <translation>סמן קורת I</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="130"/>
+        <location filename="../propertiesdialog.cpp" line="175"/>
         <source>No move</source>
         <translation>לא להזיז</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="130"/>
+        <location filename="../propertiesdialog.cpp" line="175"/>
         <source>Move start</source>
         <translation>להזיז את ההתחלה</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="130"/>
+        <location filename="../propertiesdialog.cpp" line="175"/>
         <source>Move end</source>
         <translation>להזיז את הסוף</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="135"/>
-        <location filename="../propertiesdialog.cpp" line="209"/>
+        <location filename="../propertiesdialog.cpp" line="180"/>
+        <location filename="../propertiesdialog.cpp" line="272"/>
         <source>System Default</source>
         <translation>בררת מחדל של המערכת</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="293"/>
+        <location filename="../propertiesdialog.cpp" line="360"/>
         <source>Choose a background image</source>
         <translation>בחירת תמונת רקע</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="294"/>
+        <location filename="../propertiesdialog.cpp" line="361"/>
         <source>Images (*.bmp *.png *.xpm *.jpg)</source>
         <translation>תמונות (‎*.bmp *.png *.xpm *.jpg)</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="359"/>
+        <location filename="../propertiesdialog.cpp" line="426"/>
         <source>Open or create bookmarks file</source>
         <translation>פתיחה או יצירה של קובץ סימניות</translation>
     </message>
@@ -723,32 +764,32 @@
     <name>TabWidget</name>
     <message>
         <location filename="../tabwidget.cpp" line="78"/>
-        <location filename="../tabwidget.cpp" line="224"/>
+        <location filename="../tabwidget.cpp" line="230"/>
         <source>Shell No. %1</source>
         <translation>מעטפת מס׳ %1</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="192"/>
+        <location filename="../tabwidget.cpp" line="198"/>
         <source>Tab name</source>
         <translation>שם לשונית</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="193"/>
+        <location filename="../tabwidget.cpp" line="199"/>
         <source>New tab name:</source>
         <translation>שם חדש ללשונית:</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="213"/>
+        <location filename="../tabwidget.cpp" line="219"/>
         <source>Select new tab title color</source>
         <translation>בחירת צבע כותרת חדש ללשונית</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="234"/>
+        <location filename="../tabwidget.cpp" line="240"/>
         <source>Close session</source>
         <translation>סגירת הפעלה</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="236"/>
+        <location filename="../tabwidget.cpp" line="242"/>
         <source>Change title color</source>
         <translation>החלפת צבע כותרת</translation>
     </message>
