@@ -36,284 +36,294 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="79"/>
+        <location filename="../mainwindow.cpp" line="90"/>
         <source>Bookmarks</source>
         <translation>Marcadores</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="190"/>
         <source>Press &quot;%1&quot; to see the terminal.</source>
         <translation>Prima %1 para ver o terminal.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="212"/>
+        <location filename="../mainwindow.cpp" line="232"/>
         <source>&amp;Clear Active Terminal</source>
         <translation>&amp;Limpar terminal ativo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="219"/>
+        <location filename="../mainwindow.cpp" line="239"/>
         <source>&amp;Next Tab</source>
         <translation>Separador segui&amp;nte</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="222"/>
+        <location filename="../mainwindow.cpp" line="242"/>
         <source>&amp;Previous Tab</source>
         <translation>Se&amp;parador anterior</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="225"/>
+        <location filename="../mainwindow.cpp" line="245"/>
         <source>&amp;Previous Tab in History</source>
         <translation>Se&amp;parador anterior no histórico</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="228"/>
+        <location filename="../mainwindow.cpp" line="248"/>
         <source>&amp;Next Tab in History</source>
         <translation>Separador segui&amp;nte no histórico</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="231"/>
+        <location filename="../mainwindow.cpp" line="251"/>
         <source>Move Tab &amp;Left</source>
         <translation>Mover separador para a &amp;esquerda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="234"/>
+        <location filename="../mainwindow.cpp" line="254"/>
         <source>Move Tab &amp;Right</source>
         <translation>Mover separador para a di&amp;reita</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="239"/>
+        <location filename="../mainwindow.cpp" line="259"/>
+        <source>Tab</source>
+        <translation>Tab</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="260"/>
+        <source>Go to</source>
+        <translation>Ir para</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="273"/>
         <source>Split Terminal &amp;Horizontally</source>
         <translation>Separar na &amp;horizontal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="242"/>
+        <location filename="../mainwindow.cpp" line="276"/>
         <source>Split Terminal &amp;Vertically</source>
         <translation>Separar na &amp;vertical</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="247"/>
+        <location filename="../mainwindow.cpp" line="281"/>
         <source>&amp;Collapse Subterminal</source>
         <translation>Re&amp;colher sub-terminal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="250"/>
+        <location filename="../mainwindow.cpp" line="284"/>
         <source>&amp;Top Subterminal</source>
         <translation>Sub-&amp;terminal superior</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="253"/>
+        <location filename="../mainwindow.cpp" line="287"/>
         <source>&amp;Bottom Subterminal</source>
         <translation>Su&amp;b-terminal inferior</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="256"/>
+        <location filename="../mainwindow.cpp" line="290"/>
         <source>L&amp;eft Subterminal</source>
         <translation>Sub-terminal &amp;esquerdo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="259"/>
+        <location filename="../mainwindow.cpp" line="293"/>
         <source>R&amp;ight Subterminal</source>
         <translation>Sub-terminal &amp;direito</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="266"/>
+        <location filename="../mainwindow.cpp" line="300"/>
         <source>Copy &amp;Selection</source>
         <translation>Copiar &amp;seleção</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="269"/>
+        <location filename="../mainwindow.cpp" line="303"/>
         <source>Paste Clip&amp;board</source>
         <translation>Colar da área de &amp;transferência</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="272"/>
+        <location filename="../mainwindow.cpp" line="306"/>
         <source>Paste S&amp;election</source>
         <translation>Colar da s&amp;eleção</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="275"/>
+        <location filename="../mainwindow.cpp" line="309"/>
         <source>Zoom &amp;in</source>
         <translation>Ampl&amp;iar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="278"/>
+        <location filename="../mainwindow.cpp" line="312"/>
         <source>Zoom &amp;out</source>
         <translation>Red&amp;uzir</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="281"/>
+        <location filename="../mainwindow.cpp" line="315"/>
         <source>Zoom rese&amp;t</source>
         <translation>&amp;Repor ampliação</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="286"/>
+        <location filename="../mainwindow.cpp" line="320"/>
         <source>&amp;Find...</source>
         <translation>&amp;Localizar...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="294"/>
+        <location filename="../mainwindow.cpp" line="328"/>
         <source>&amp;Save Session</source>
         <translation>Guardar &amp;sessão</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="300"/>
+        <location filename="../mainwindow.cpp" line="334"/>
         <source>&amp;Load Session</source>
         <translation>&amp;Carregar sessão</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="307"/>
+        <location filename="../mainwindow.cpp" line="341"/>
         <source>&amp;Toggle Menu</source>
         <translation>Al&amp;ternar menu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="312"/>
+        <location filename="../mainwindow.cpp" line="346"/>
         <source>Rename session</source>
         <translation>Renomear sessão</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="320"/>
+        <location filename="../mainwindow.cpp" line="355"/>
         <source>&amp;New Tab</source>
         <translation>&amp;Novo separador</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="359"/>
         <source>New Tab From &amp;Preset</source>
         <translation>Novo separador de &amp;pré-ajuste</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="325"/>
+        <location filename="../mainwindow.cpp" line="360"/>
         <source>1 &amp;Terminal</source>
         <translation>1 &amp;terminal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="327"/>
+        <location filename="../mainwindow.cpp" line="362"/>
         <source>2 &amp;Horizontal Terminals</source>
         <translation>2 terminais &amp;horizontais</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="329"/>
+        <location filename="../mainwindow.cpp" line="364"/>
         <source>2 &amp;Vertical Terminals</source>
         <translation>2 terminais &amp;verticais</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="331"/>
+        <location filename="../mainwindow.cpp" line="366"/>
         <source>4 Terminal&amp;s</source>
         <translation>4 terminai&amp;s</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="337"/>
+        <location filename="../mainwindow.cpp" line="372"/>
         <source>&amp;Close Tab</source>
         <translation>Fe&amp;char separador</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="340"/>
+        <location filename="../mainwindow.cpp" line="375"/>
         <source>&amp;New Window</source>
         <translation>&amp;Nova janela</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="380"/>
         <source>&amp;Preferences...</source>
         <translation>&amp;Preferências...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="349"/>
+        <location filename="../mainwindow.cpp" line="384"/>
         <source>&amp;Quit</source>
         <translation>&amp;Sair</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="355"/>
+        <location filename="../mainwindow.cpp" line="390"/>
         <source>&amp;Hide Window Borders</source>
         <translation>&amp;Ocultar contornos da janela</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="366"/>
+        <location filename="../mainwindow.cpp" line="401"/>
         <source>&amp;Show Tab Bar</source>
         <translation>Mo&amp;strar barra de separadores</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../mainwindow.cpp" line="409"/>
         <source>Fullscreen</source>
         <translation>Ecrã completo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="380"/>
+        <location filename="../mainwindow.cpp" line="415"/>
         <source>Toggle Bookmarks</source>
         <translation>Alternar marcadores</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="388"/>
+        <location filename="../mainwindow.cpp" line="423"/>
         <source>&amp;Bottom</source>
         <translation>&amp;Baixo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="389"/>
+        <location filename="../mainwindow.cpp" line="424"/>
         <source>&amp;Top</source>
         <translation>&amp;Cima</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="390"/>
-        <location filename="../mainwindow.cpp" line="426"/>
+        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="../mainwindow.cpp" line="461"/>
         <source>&amp;Right</source>
         <translation>&amp;Direita</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="391"/>
-        <location filename="../mainwindow.cpp" line="427"/>
+        <location filename="../mainwindow.cpp" line="426"/>
+        <location filename="../mainwindow.cpp" line="462"/>
         <source>&amp;Left</source>
         <translation>&amp;Esquerda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="409"/>
+        <location filename="../mainwindow.cpp" line="444"/>
         <source>&amp;Tabs Layout</source>
         <translation>&amp;Posição dos separadores</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="../mainwindow.cpp" line="460"/>
         <source>&amp;None</source>
         <translation>&amp;Nenhuma</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="443"/>
+        <location filename="../mainwindow.cpp" line="478"/>
         <source>S&amp;crollbar Layout</source>
         <translation>Posição da barra de deslo&amp;cação</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="456"/>
+        <location filename="../mainwindow.cpp" line="491"/>
         <source>&amp;BlockCursor</source>
         <translation>&amp;Bloco</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="457"/>
+        <location filename="../mainwindow.cpp" line="492"/>
         <source>&amp;UnderlineCursor</source>
         <translation>S&amp;ublinhado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="458"/>
+        <location filename="../mainwindow.cpp" line="493"/>
         <source>&amp;IBeamCursor</source>
         <translation>&amp;Ibeam</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="475"/>
+        <location filename="../mainwindow.cpp" line="510"/>
         <source>&amp;Keyboard Cursor Shape</source>
         <translation>&amp;Forma do cursor de teclado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="566"/>
+        <location filename="../mainwindow.cpp" line="599"/>
         <source>Exit QTerminal</source>
         <translation>Sair do QTerminal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="568"/>
+        <location filename="../mainwindow.cpp" line="601"/>
         <source>Do not ask again</source>
         <translation>Não perguntar novamente</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="576"/>
+        <location filename="../mainwindow.cpp" line="609"/>
         <source>Are you sure you want to exit?</source>
         <translation>Tem a certeza de que deseja sair?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="607"/>
+        <location filename="../mainwindow.cpp" line="640"/>
         <source>A lightweight multiplatform terminal emulator</source>
         <translation>Um emulador de terminal multiplataforma</translation>
     </message>
@@ -321,12 +331,12 @@
 <context>
     <name>PropertiesDialog</name>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="449"/>
+        <location filename="../forms/propertiesdialog.ui" line="530"/>
         <source>Emulation</source>
         <translation>Emulação</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="62"/>
+        <location filename="../forms/propertiesdialog.ui" line="47"/>
         <source>Shortcuts</source>
         <translation>Atalhos</translation>
     </message>
@@ -336,364 +346,395 @@
         <translation>Definições do terminal</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="52"/>
+        <location filename="../forms/propertiesdialog.ui" line="31"/>
         <source>Appearance</source>
         <translation>Aparência</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="57"/>
-        <location filename="../forms/propertiesdialog.ui" line="474"/>
+        <location filename="../forms/propertiesdialog.ui" line="39"/>
+        <location filename="../forms/propertiesdialog.ui" line="555"/>
         <source>Behavior</source>
         <translation>Comportamento</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="67"/>
+        <location filename="../forms/propertiesdialog.ui" line="55"/>
         <source>Dropdown</source>
         <translation>Suspenso</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="72"/>
+        <location filename="../forms/propertiesdialog.ui" line="63"/>
         <source>Bookmarks</source>
         <translation>Marcadores</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="90"/>
+        <location filename="../forms/propertiesdialog.ui" line="258"/>
         <source>Hide tab bar with only one tab</source>
         <translation>Ocultar barra de separadores se apenas existir um</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="100"/>
+        <location filename="../forms/propertiesdialog.ui" line="275"/>
         <source>Color scheme</source>
         <translation>Esquema de cores</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="254"/>
+        <location filename="../forms/propertiesdialog.ui" line="184"/>
         <source>&amp;Change...</source>
         <translation>&amp;Alterar...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="296"/>
+        <location filename="../forms/propertiesdialog.ui" line="238"/>
         <source>Widget style</source>
         <translation>Estilo do widget</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="110"/>
+        <location filename="../forms/propertiesdialog.ui" line="335"/>
         <source>Scrollbar position</source>
         <translation>Posição da barra de deslocação</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="267"/>
+        <location filename="../forms/propertiesdialog.ui" line="418"/>
         <source>Tabs position</source>
         <translation>Posição dos separadores</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="319"/>
+        <location filename="../forms/propertiesdialog.ui" line="194"/>
         <source>Show the menu bar</source>
         <translation>Mostrar barra de menu</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="136"/>
+        <location filename="../forms/propertiesdialog.ui" line="368"/>
         <source>Show a border around the current terminal</source>
         <translation>Mostrar contornos do terminal</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="153"/>
+        <location filename="../forms/propertiesdialog.ui" line="358"/>
         <source>Application transparency</source>
         <translation>Transparência da aplicação</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="143"/>
+        <location filename="../forms/propertiesdialog.ui" line="345"/>
         <source>Terminal transparency</source>
         <translation>Transparência do terminal</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="120"/>
+        <location filename="../forms/propertiesdialog.ui" line="204"/>
         <source>Start with preset:</source>
         <translation>Iniciar com pré-ajuste:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="164"/>
+        <location filename="../forms/propertiesdialog.ui" line="215"/>
         <source>None (single terminal)</source>
         <translation>Não (um terminal)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="169"/>
+        <location filename="../forms/propertiesdialog.ui" line="220"/>
         <source>2 terminals horizontally</source>
         <translation>2 terminais horizontais</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="174"/>
+        <location filename="../forms/propertiesdialog.ui" line="225"/>
         <source>2 terminals vertically</source>
         <translation>2 terminais verticais</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="179"/>
+        <location filename="../forms/propertiesdialog.ui" line="230"/>
         <source>4 terminals</source>
         <translation>4 terminais</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="218"/>
+        <location filename="../forms/propertiesdialog.ui" line="148"/>
         <source>Font</source>
         <translation>Tipo de letra</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="326"/>
+        <location filename="../forms/propertiesdialog.ui" line="299"/>
         <source>Cursor shape</source>
         <translation>Forma do cursor</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="385"/>
+        <location filename="../forms/propertiesdialog.ui" line="435"/>
         <source>Fixed tab width:</source>
         <translation>Separador com largura fixa:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="415"/>
+        <location filename="../forms/propertiesdialog.ui" line="248"/>
         <source>Terminal margin</source>
         <translation>Margem do terminal</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="458"/>
+        <location filename="../forms/propertiesdialog.ui" line="459"/>
+        <source>Use box drawing characters contained in the font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="466"/>
+        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
+        <translation>Os aceleradores são ativados com a tecla Alt e podem interferir com o terminal.</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="469"/>
+        <source>No menu bar accelerator</source>
+        <translation>Não utilizar barra de menu Aceleradores</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="539"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;O comportamento a emular. Tenha em atenção que esta opção não tem que ser igual à do sistema operativo.&lt;/p&gt;&lt;p&gt;A emulação &lt;span style=&quot; font-weight:600;&quot;&gt;padrão&lt;/span&gt; possui um conjunto mínimo de funcionalidades.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="480"/>
+        <location filename="../forms/propertiesdialog.ui" line="561"/>
         <source>Action after paste</source>
         <translation>Ação depois de colar</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="490"/>
+        <location filename="../forms/propertiesdialog.ui" line="571"/>
         <source>Confirm multiline paste</source>
         <translation>Confirmação de colagem</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="497"/>
+        <location filename="../forms/propertiesdialog.ui" line="578"/>
         <source>Trim trailing newlines in pasted text</source>
         <translation>Remover início de novas linhas ao colar texto</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="530"/>
+        <location filename="../forms/propertiesdialog.ui" line="598"/>
         <source>Open new terminals in current working directory</source>
         <translation>Abrir novos terminais no diretório de trabalho atual</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="537"/>
+        <location filename="../forms/propertiesdialog.ui" line="605"/>
         <source>Save Size when closing</source>
         <translation>Guardar tamanho ao fechar</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="544"/>
+        <location filename="../forms/propertiesdialog.ui" line="612"/>
         <source>Save Position when closing</source>
         <translation>Guardar posição ao fechar</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="551"/>
+        <location filename="../forms/propertiesdialog.ui" line="619"/>
         <source>Ask for confirmation when closing</source>
         <translation>Confirmar antes de fechar</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="561"/>
+        <location filename="../forms/propertiesdialog.ui" line="629"/>
         <source>Unlimited history</source>
         <translation>Histórico ilimitado</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="568"/>
+        <location filename="../forms/propertiesdialog.ui" line="636"/>
         <source>History size (in lines)</source>
         <translation>Limitar histórico (linhas)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="575"/>
+        <location filename="../forms/propertiesdialog.ui" line="643"/>
         <source>Default $TERM</source>
         <translation>$TERM padrão</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="666"/>
+        <location filename="../forms/propertiesdialog.ui" line="681"/>
+        <source>Start with this size:</source>
+        <translation>Iniciar com este tamanho:</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="688"/>
+        <location filename="../forms/propertiesdialog.ui" line="702"/>
+        <source> px</source>
+        <translation> px</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="709"/>
+        <source>Get current size</source>
+        <translation>Obter tamanho atual</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="802"/>
         <source>Height</source>
         <translation>Altura</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="676"/>
-        <location filename="../forms/propertiesdialog.ui" line="693"/>
+        <location filename="../forms/propertiesdialog.ui" line="812"/>
+        <location filename="../forms/propertiesdialog.ui" line="829"/>
         <source>%</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="683"/>
+        <location filename="../forms/propertiesdialog.ui" line="819"/>
         <source>Width</source>
         <translation>Largura</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="739"/>
+        <location filename="../forms/propertiesdialog.ui" line="875"/>
         <source>Edit bookmark file contents</source>
         <translation>Editar conteúdo do ficheiro de marcadores</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="761"/>
+        <location filename="../forms/propertiesdialog.ui" line="897"/>
         <source>Enable bookmarks</source>
         <translation>Ativar marcadores</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="770"/>
+        <location filename="../forms/propertiesdialog.ui" line="906"/>
         <source>Bookmark file</source>
         <translation>Ficheiro de marcadores</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="648"/>
+        <location filename="../forms/propertiesdialog.ui" line="784"/>
         <source>Show on start</source>
         <translation>Mostrar ao iniciar</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="336"/>
+        <location filename="../forms/propertiesdialog.ui" line="428"/>
         <source>Change window title based on current terminal</source>
         <translation>Alterar título da janela de acordo com o terminal atual</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="343"/>
+        <location filename="../forms/propertiesdialog.ui" line="445"/>
         <source>Change window icon based on current terminal</source>
         <translation>Alterar ícone da janela de acordo com o terminal atual</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="350"/>
+        <location filename="../forms/propertiesdialog.ui" line="382"/>
         <source>Enable bi-directional text support</source>
         <translation>Ativar suporte a texto bidirecional</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="357"/>
+        <location filename="../forms/propertiesdialog.ui" line="265"/>
         <source>Background image:</source>
         <translation>Imagem de fundo:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="369"/>
+        <location filename="../forms/propertiesdialog.ui" line="290"/>
         <source>Select</source>
         <translation>Selecionar</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="378"/>
+        <location filename="../forms/propertiesdialog.ui" line="452"/>
         <source>Show terminal size on resize</source>
         <translation>Mostrar tamanho do terminal ao redimensionar</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="395"/>
-        <location filename="../forms/propertiesdialog.ui" line="425"/>
+        <location filename="../forms/propertiesdialog.ui" line="375"/>
+        <location filename="../forms/propertiesdialog.ui" line="408"/>
         <source>px</source>
         <translation>px</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="405"/>
+        <location filename="../forms/propertiesdialog.ui" line="325"/>
         <source>Show close button on each tab</source>
         <translation>Mostrar botão de fecho nos separadores</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="655"/>
+        <location filename="../forms/propertiesdialog.ui" line="791"/>
         <source>Size</source>
         <translation>Tamanho</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="707"/>
+        <location filename="../forms/propertiesdialog.ui" line="843"/>
         <source>Shortcut:</source>
         <translation>Atalho:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="783"/>
+        <location filename="../forms/propertiesdialog.ui" line="919"/>
         <source>Find...</source>
         <translation>Localizar...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="792"/>
+        <location filename="../forms/propertiesdialog.ui" line="928"/>
         <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
         <translation>Pode especificar a localização do ficheiro de marcadores. Permite a partilha de marcadores através do Own Cloud ou do Dropbox.</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="187"/>
-        <location filename="../forms/propertiesdialog.ui" line="280"/>
+        <location filename="../forms/propertiesdialog.ui" line="117"/>
+        <location filename="../forms/propertiesdialog.ui" line="389"/>
         <source> %</source>
         <translation> %</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="631"/>
+        <location filename="../forms/propertiesdialog.ui" line="767"/>
         <source>Shortcut</source>
         <translation>Atalho</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="636"/>
+        <location filename="../forms/propertiesdialog.ui" line="772"/>
         <source>Key</source>
         <translation>Tecla</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="101"/>
+        <location filename="../propertiesdialog.cpp" line="145"/>
         <source>No scrollbar</source>
         <translation>Sem barra de deslocação</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="101"/>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="145"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Left</source>
         <translation>Esquerda</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="101"/>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="145"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Right</source>
         <translation>Direita</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Top</source>
         <translation>Cima</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="107"/>
+        <location filename="../propertiesdialog.cpp" line="151"/>
         <source>Bottom</source>
         <translation>Baixo</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="118"/>
+        <location filename="../propertiesdialog.cpp" line="162"/>
         <source>BlockCursor</source>
         <translation>Bloco</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="118"/>
+        <location filename="../propertiesdialog.cpp" line="162"/>
         <source>UnderlineCursor</source>
         <translation>Sublinhado</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="118"/>
+        <location filename="../propertiesdialog.cpp" line="162"/>
         <source>IBeamCursor</source>
         <translation>Ibeam</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="130"/>
+        <location filename="../propertiesdialog.cpp" line="175"/>
         <source>No move</source>
         <translation>Não mover</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="130"/>
+        <location filename="../propertiesdialog.cpp" line="175"/>
         <source>Move start</source>
         <translation>Mover para o inicio</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="130"/>
+        <location filename="../propertiesdialog.cpp" line="175"/>
         <source>Move end</source>
         <translation>Mover para o fim</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="135"/>
-        <location filename="../propertiesdialog.cpp" line="209"/>
+        <location filename="../propertiesdialog.cpp" line="180"/>
+        <location filename="../propertiesdialog.cpp" line="272"/>
         <source>System Default</source>
         <translation>Predefinições</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="293"/>
+        <location filename="../propertiesdialog.cpp" line="360"/>
         <source>Choose a background image</source>
         <translation>Escolha a imagem de fundo</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="294"/>
+        <location filename="../propertiesdialog.cpp" line="361"/>
         <source>Images (*.bmp *.png *.xpm *.jpg)</source>
         <translation>Imagens (*.bmp *.png *.xpm *.jpg)</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="359"/>
+        <location filename="../propertiesdialog.cpp" line="426"/>
         <source>Open or create bookmarks file</source>
         <translation>Abrir ou criar um ficheiro de marcadores</translation>
     </message>
@@ -723,32 +764,32 @@
     <name>TabWidget</name>
     <message>
         <location filename="../tabwidget.cpp" line="78"/>
-        <location filename="../tabwidget.cpp" line="224"/>
+        <location filename="../tabwidget.cpp" line="230"/>
         <source>Shell No. %1</source>
         <translation>Consola n.º %1</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="192"/>
+        <location filename="../tabwidget.cpp" line="198"/>
         <source>Tab name</source>
         <translation>Nome do separador</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="193"/>
+        <location filename="../tabwidget.cpp" line="199"/>
         <source>New tab name:</source>
         <translation>Nome do novo separador:</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="213"/>
+        <location filename="../tabwidget.cpp" line="219"/>
         <source>Select new tab title color</source>
         <translation>Selecione a cor do título do novo separador</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="234"/>
+        <location filename="../tabwidget.cpp" line="240"/>
         <source>Close session</source>
         <translation>Fechar sessão</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="236"/>
+        <location filename="../tabwidget.cpp" line="242"/>
         <source>Change title color</source>
         <translation>Alterar cor do título</translation>
     </message>
